searchData={"items":[{"type":"module","title":"Anthropic","doc":"Provides an unofficial Elixir wrapper for the [Anthropic API](https://docs.anthropic.com/claude/reference/messages_post), facilitating access to the Claude LLM model.\nThis module handles configuration, request preparation, and communication with the API, offering an idiomatic Elixir interface to the Anthropic AI capabilities.","ref":"Anthropic.html"},{"type":"module","title":"Key Features - Anthropic","doc":"- **Tool Invocations**: Allows registering and executing custom tool modules that implement the `Anthropic.Tools.ToolBehaviour`, enabling dynamic handling of function invocations from the assistant's responses.\n- **Configuration Management**: Centralizes settings for the Anthropic API, such as model specifications, API keys, and request parameters, ensuring a consistent request configuration.\n- **Message Handling**: Supports adding various types of messages to the request, including text and image content, enhancing interaction with the Anthropic AI.\n- **Error Handling**: Implements comprehensive error handling for both request generation and response parsing, providing clear feedback on failures.\n- **Telemetry Integration**: Integrates with Elixir's `:telemetry` library to emit events for key operations, enabling monitoring and observability.","ref":"Anthropic.html#module-key-features"},{"type":"module","title":"Configuration - Anthropic","doc":"Please refer to `Antrhopic.Config` for more details.","ref":"Anthropic.html#module-configuration"},{"type":"module","title":"Usage - Anthropic","doc":"Start by configuring the API settings, then use the provided functions to add messages or images to your request. Finally, send the request to the Anthropic API and handle the response:\n\n```elixir\n{:ok, response, updated_request} =\n  Anthropic.new(max_tokens: 500, api_key: \"API_KEY\")\n  |> Anthropic.add_user_message(config, \"Hello, Anthropic!\")\n  |> Anthropic.request_next_message()\n```","ref":"Anthropic.html#module-usage"},{"type":"module","title":"Error Handling - Anthropic","doc":"The module returns errors in the format `{:error, reason}`, where `reason` can be:\n\n- A map containing error details from the Anthropic API, with an \"error\" key indicating the type of error.\n- A `Finch.Error` struct if there was an issue with the HTTP request.\n- A `Jason.DecodeError` struct if there was an issue decoding the JSON response.\n- An `:unknown_error` atom if an unexpected error occurred.","ref":"Anthropic.html#module-error-handling"},{"type":"module","title":"Telemetry - Anthropic","doc":"This module emits several `:telemetry` events to help monitor its operations, which can be observed for logging, metrics, or operational insights.\n\n#","ref":"Anthropic.html#module-telemetry"},{"type":"module","title":"Events - Anthropic","doc":"- `[:anthropic, :request_next_message, :start]` - Emitted at the beginning of a request to the Anthropic API.\n  - Measurements: `%{system_time: integer()}`\n  - Metadata: `%{model: String.t(), max_tokens: integer()}`\n\n- `[:anthropic, :request_next_message, :stop]` - Emitted after a request to the Anthropic API successfully completes.\n  - Measurements: `%{duration: integer()}`\n  - Metadata: `%{model: String.t(), max_tokens: integer(), input_tokens: integer(), output_tokens: integer()}`\n\n- `[:anthropic, :request_next_message, :exception]` - Emitted if an exception occurs during a request to the Anthropic API.\n  - Measurements: `%{duration: integer()}`\n  - Metadata: `%{model: String.t(), max_tokens: integer(), kind: Exception.kind(), reason: term(), stacktrace: Exception.stacktrace()}`\n\n#","ref":"Anthropic.html#module-events"},{"type":"module","title":"Metrics - Anthropic","doc":"Each telemetry event includes metadata with the following information:\n\n- `:model` - The name of the model used for the request.\n- `:max_tokens` - The maximum number of tokens allowed in the generated response.\n- `:input_tokens` - The number of tokens in the input message (only available in the `:stop` event).\n- `:output_tokens` - The number of tokens in the generated response (only available in the `:stop` event).\n- `:kind` - The type of exception that occurred (only available in the `:exception` event).\n- `:reason` - The reason for the exception (only available in the `:exception` event).\n- `:stacktrace` - The stacktrace of the exception (only available in the `:exception` event).\n\nBy attaching to these events, you can monitor the performance and health of your Anthropic API integration, track usage metrics, and handle exceptions as needed.","ref":"Anthropic.html#module-metrics"},{"type":"function","title":"Anthropic.add_assistant_message/2","doc":"Adds a assistant message to the request.","ref":"Anthropic.html#add_assistant_message/2"},{"type":"function","title":"Parameters - Anthropic.add_assistant_message/2","doc":"- `request`: The `Anthropic.Messages.Request` struct to which the assistant message will be added.\n- `message`: The content of the assistant message.","ref":"Anthropic.html#add_assistant_message/2-parameters"},{"type":"function","title":"Returns - Anthropic.add_assistant_message/2","doc":"- The updated `Anthropic.Messages.Request` struct with the assistant message added.","ref":"Anthropic.html#add_assistant_message/2-returns"},{"type":"function","title":"Anthropic.add_message/3","doc":"Adds a message to the request with a specified role.","ref":"Anthropic.html#add_message/3"},{"type":"function","title":"Parameters - Anthropic.add_message/3","doc":"- `request`: The `Anthropic.Messages.Request` struct to which the message will be added.\n- `role`: The role of the message (e.g., `:user` or `:assistant`).\n- `message`: The content of the message, which can be one of the following:\n  - A binary string representing a single text message, that will be converted to a content of type `text`.\n  - A list of binary strings representing multiple text messages.\n  - A content object representing a single message with a specific type (e.g., text or image).\n  - A list of content objects representing multiple messages with specific types.","ref":"Anthropic.html#add_message/3-parameters"},{"type":"function","title":"Returns - Anthropic.add_message/3","doc":"- The updated `Anthropic.Messages.Request` struct with the new message(s) added.","ref":"Anthropic.html#add_message/3-returns"},{"type":"function","title":"Examples - Anthropic.add_message/3","doc":"```elixir\n# Adding a single text message\nrequest = Anthropic.add_message(request, :user, \"Hello!\")\n\n# Adding multiple text messages\nrequest = Anthropic.add_message(request, :user, [\"Hello!\", \"How are you?\"])\n\n# Adding a single content object\ncontent_object = %{type: \"text\", text: \"Hello!\"}\nrequest = Anthropic.add_message(request, :user, content_object)\n\n# Adding multiple content objects\ncontent_objects = [\n  %{type: \"text\", text: \"Hello!\"},\n  %{type: \"image\", source: %{data: \"base64_encoded_data\", type: \"base64\", media_type: \"image/png\"}}\n]\nrequest = Anthropic.add_message(request, :user, content_objects)\n```","ref":"Anthropic.html#add_message/3-examples"},{"type":"function","title":"Anthropic.add_system_message/2","doc":"Adds a system message to the request.","ref":"Anthropic.html#add_system_message/2"},{"type":"function","title":"Parameters - Anthropic.add_system_message/2","doc":"- `request`: A `Anthropic.Messages.Request` struct to which the system message will be added.\n- `message`: The system message to add, must be a binary string.","ref":"Anthropic.html#add_system_message/2-parameters"},{"type":"function","title":"Returns - Anthropic.add_system_message/2","doc":"- The updated `Anthropic.Messages.Request` struct with the system message added.","ref":"Anthropic.html#add_system_message/2-returns"},{"type":"function","title":"Errors - Anthropic.add_system_message/2","doc":"- Raises `ArgumentError` if the message is not a binary string.","ref":"Anthropic.html#add_system_message/2-errors"},{"type":"function","title":"Anthropic.add_user_image/2","doc":"Adds an image message to the request.\n\nProcesses the given image, converts it to a base64 encoded string, and adds it as a message to the request with a role of `:user`.","ref":"Anthropic.html#add_user_image/2"},{"type":"function","title":"Parameters - Anthropic.add_user_image/2","doc":"- `request`: The `Anthropic.Messages.Request` struct to which the image message will be added.\n- `image_data`: A tuple consisting of the input type and the image path or binary data. The input type should be one of `:path`, `:binary`, or `:base64`, indicating how the image is provided.","ref":"Anthropic.html#add_user_image/2-parameters"},{"type":"function","title":"Returns - Anthropic.add_user_image/2","doc":"- The updated `Anthropic.Messages.Request` struct with the image message added.","ref":"Anthropic.html#add_user_image/2-returns"},{"type":"function","title":"Examples - Anthropic.add_user_image/2","doc":"Anthropic.add_user_image(request, {:path, \"/path/to/image.png\"})\n    # Adds an image from a local file path\n\n    Anthropic.add_user_image(request, {:binary, < >})\n    # Adds an image from binary data\n\n    Anthropic.add_user_image(request, {:base64, \"base64 encoded image data\"})\n    # Adds an image from a base64 encoded string","ref":"Anthropic.html#add_user_image/2-examples"},{"type":"function","title":"Errors - Anthropic.add_user_image/2","doc":"- Returns `{:error, reason}` if the image processing fails, where `reason` is a descriptive error message.","ref":"Anthropic.html#add_user_image/2-errors"},{"type":"function","title":"Anthropic.add_user_message/2","doc":"A shorthand to add a user message to a request.","ref":"Anthropic.html#add_user_message/2"},{"type":"function","title":"Parameters - Anthropic.add_user_message/2","doc":"- `request`: The `Anthropic.Messages.Request` struct to which the user message will be added.\n- `message`: The content of the user message.","ref":"Anthropic.html#add_user_message/2-parameters"},{"type":"function","title":"Returns - Anthropic.add_user_message/2","doc":"- The updated `Anthropic.Messages.Request` struct with the user message added.","ref":"Anthropic.html#add_user_message/2-returns"},{"type":"function","title":"Anthropic.new/1","doc":"Initializes a new `Anthropic.Messages.Request` struct with the given options, merging them with the default configuration `Anthropic.Config`.","ref":"Anthropic.html#new/1"},{"type":"function","title":"Parameters - Anthropic.new/1","doc":"- `opts`: (Optional) A keyword list of options to override the default configuration settings. Refer to `Anthropic.Messages.Request` for options that can be overridden.","ref":"Anthropic.html#new/1-parameters"},{"type":"function","title":"Returns - Anthropic.new/1","doc":"- A new `Anthropic.Messages.Request` struct populated with the merged configuration options.","ref":"Anthropic.html#new/1-returns"},{"type":"function","title":"Anthropic.process_invocations/1","doc":"Processes the tool invocations present in the assistant's response.\n\nThis function takes the result of `request_next_message/1` and checks if there are any tool invocations in the response.\nIf invocations are found, it executes each one using the registered tools and appends the results to the conversation.\nIt then sends the updated conversation back to the API for further processing.","ref":"Anthropic.html#process_invocations/1"},{"type":"function","title":"Parameters - Anthropic.process_invocations/1","doc":"- `result`: The result of `request_next_message/1`, which can be either `{:ok, response, request}` or `{:error, response, request}`.\n- `request`: A `Anthropic.Messages.Request`.","ref":"Anthropic.html#process_invocations/1-parameters"},{"type":"function","title":"Returns - Anthropic.process_invocations/1","doc":"- `{:ok, response, updated_request}`: If the invocations are processed successfully, where `response` is the original response\nfrom the API, and `updated_request` is the request struct updated with the invocation results.\n- `{:error, response, request}`: If an error occurs during the processing of invocations, where `response` contains the error\ndetails, and `request` is the original request struct.","ref":"Anthropic.html#process_invocations/1-returns"},{"type":"function","title":"Raises - Anthropic.process_invocations/1","doc":"- `ArgumentError`: If a tool invocation fails due to the specified tool not being registered or if there's an error during the\nexecution of the tool.\n\nThis function is responsible for handling the dynamic execution of tools based on the assistant's responses. It allows for a\nmore interactive and extensible conversation flow by processing tool invocations and incorporating their results into the ongoing conversation.","ref":"Anthropic.html#process_invocations/1-raises"},{"type":"function","title":"Anthropic.register_tool/2","doc":"Registers a tool module with the given request.\n\nThis function allows developers to register tools that implement the `Anthropic.Tools.ToolBehaviour`.\nRegistered tools will be added to the system message automaticaly at the time of the request, and will be made\navailable to the assistant. Once the assistant invokes a function call, it will be processed and the result will be returned\nback to the assistant.\n\nThe `Anthropic.Tools.ToolBehaviour` requires the following callbacks to be implemented:\n\n- `description/0`: Returns a string describing the purpose and functionality of the tool.\n- `parameters/0`: Returns a list of parameter specifications, each represented as a tuple `{name, type, description}`.\n  - `name`: An atom representing the name of the parameter.\n  - `type`: The type of the parameter, which can be `:string`, `:float`, or `:integer`.\n  - `description`: A string describing the parameter.\n- `invoke/1`: Accepts a Keyword list of arguments and returns the result of the tool invocation as a string.\n\nBy implementing these callbacks, developers can create custom tools that can be dynamically invoked by the assistant during the conversation.","ref":"Anthropic.html#register_tool/2"},{"type":"function","title":"Parameters - Anthropic.register_tool/2","doc":"- `request`: The `Anthropic.Messages.Request` struct that represents the current state of the conversation.\n- `tool_module`: The module that implements the `Anthropic.Tools.ToolBehaviour`, to be registered with the request.","ref":"Anthropic.html#register_tool/2-parameters"},{"type":"function","title":"Returns - Anthropic.register_tool/2","doc":"- An updated `Anthropic.Messages.Request` struct with the tool module registered.","ref":"Anthropic.html#register_tool/2-returns"},{"type":"function","title":"Examples - Anthropic.register_tool/2","doc":"```elixir\ndefmodule MyCustomTool do\n  @behaviour Anthropic.Tools.ToolBehaviour\n\n  def description, do: \"A custom tool for demonstration purposes\"\n\n  def parameters, do: [\n    {:name, :string, \"The name of the person\"},\n    {:age, :integer, \"The age of the person\"}\n  ]\n\n  def invoke([name, age]) do\n    \"Hello, #{name}! You are #{age} years old.\"\n  end\nend\n\nrequest = Anthropic.register_tool(request, MyCustomTool)\n```","ref":"Anthropic.html#register_tool/2-examples"},{"type":"function","title":"Anthropic.remove_tool/2","doc":"","ref":"Anthropic.html#remove_tool/2"},{"type":"function","title":"Anthropic.request_next_message/2","doc":"Sends the current request to the Anthropic API and awaits the next message in the conversation.\n\nThis function encapsulates the process of sending the prepared request to the Anthropic API, parsing the response, and preparing the next step of the conversation based on the API's response.","ref":"Anthropic.html#request_next_message/2"},{"type":"function","title":"Parameters - Anthropic.request_next_message/2","doc":"- `request`: The `Anthropic.Messages.Request` struct that contains the current state of the conversation.\n- `http_client_opts`: (Optional) A list of options for the HTTP client used to make the request. These options are passed directly to the HTTP client.","ref":"Anthropic.html#request_next_message/2-parameters"},{"type":"function","title":"Returns - Anthropic.request_next_message/2","doc":"- On success, returns a tuple `{:ok, response_content, updated_request}` where `response_content` is the content of the response from the API, and `updated_request` is the updated request struct including the response message.\n- On failure, returns a tuple `{:error, response, request}` where `response` contains error information provided by the API or HTTP client.\n\nThis function is the main mechanism through which conversations are advanced, by sending user or assistant messages to the API and incorporating the API's responses into the ongoing conversation.","ref":"Anthropic.html#request_next_message/2-returns"},{"type":"type","title":"Anthropic.message/0","doc":"","ref":"Anthropic.html#t:message/0"},{"type":"type","title":"Anthropic.role/0","doc":"","ref":"Anthropic.html#t:role/0"},{"type":"module","title":"Anthropic.Config","doc":"Module provides struct for Anthropic.Config, and provides validations for various config options.","ref":"Anthropic.Config.html"},{"type":"module","title":"Configuration - Anthropic.Config","doc":"The following configuration options are available:\n\n- `:api_key` - The API key for authenticating requests to the Anthropic API (required).\n- `:model` - The name of the model to use for generating responses (default: \"claude-3-opus-20240229\").\n- `:max_tokens` - The maximum number of tokens allowed in the generated response (default: 1000).\n- `:temperature` - The sampling temperature for controlling response randomness (default: 1.0).\n- `:top_p` - The cumulative probability threshold for nucleus sampling (default: 1.0).\n- `:top_k` - The number of top tokens to consider for sampling (default: 1).\n- `:anthropic_version` - The version of the Anthropic API to use (default: \"2023-06-01\").\n- `:api_url` - The URL of the Anthropic API (default: \"https://api.anthropic.com/v1\").\n\nThese options can be set in your application's configuration file:\n\n```elixir\nconfig :anthropic,\n  api_key: \"your_api_key\",\n  model: \"claude-v1\",\n  max_tokens: 500,\n  temperature: 0.7,\n  top_p: 0.9,\n  top_k: 5\n```","ref":"Anthropic.Config.html#module-configuration"},{"type":"function","title":"Anthropic.Config.build_system_configs/1","doc":"","ref":"Anthropic.Config.html#build_system_configs/1"},{"type":"function","title":"Anthropic.Config.create/1","doc":"","ref":"Anthropic.Config.html#create/1"},{"type":"function","title":"Anthropic.Config.validate_config/1","doc":"","ref":"Anthropic.Config.html#validate_config/1"},{"type":"type","title":"Anthropic.Config.config_option/0","doc":"","ref":"Anthropic.Config.html#t:config_option/0"},{"type":"type","title":"Anthropic.Config.config_options/0","doc":"","ref":"Anthropic.Config.html#t:config_options/0"},{"type":"type","title":"Anthropic.Config.t/0","doc":"","ref":"Anthropic.Config.html#t:t/0"},{"type":"behaviour","title":"Anthropic.HTTPClient","doc":"","ref":"Anthropic.HTTPClient.html"},{"type":"function","title":"Anthropic.HTTPClient.build/5","doc":"","ref":"Anthropic.HTTPClient.html#build/5"},{"type":"callback","title":"Anthropic.HTTPClient.build/5","doc":"","ref":"Anthropic.HTTPClient.html#c:build/5"},{"type":"function","title":"Anthropic.HTTPClient.request/3","doc":"","ref":"Anthropic.HTTPClient.html#request/3"},{"type":"callback","title":"Anthropic.HTTPClient.request/3","doc":"","ref":"Anthropic.HTTPClient.html#c:request/3"},{"type":"module","title":"Anthropic.HttpClient.Utils","doc":"Provides utility functions for constructing HTTP requests for use with the Finch HTTP client.\nThis module facilitates the assembly of request paths and headers based on configuration options,\nspecifically tailored for interacting with the Anthropic API.","ref":"Anthropic.HttpClient.Utils.html"},{"type":"function","title":"Anthropic.HttpClient.Utils.build_header/1","doc":"Constructs the headers for an HTTP request based on the provided `Anthropic.Config` struct.\n\nThis function generates a list of HTTP headers necessary for making requests to the Anthropic API, including authentication and content type headers.","ref":"Anthropic.HttpClient.Utils.html#build_header/1"},{"type":"function","title":"Parameters - Anthropic.HttpClient.Utils.build_header/1","doc":"- `opts`: The `Anthropic.Config` struct containing configuration options like the API key and the API version.","ref":"Anthropic.HttpClient.Utils.html#build_header/1-parameters"},{"type":"function","title":"Returns - Anthropic.HttpClient.Utils.build_header/1","doc":"- A list of tuples where each tuple represents an HTTP header. Includes the API key, Anthropic version, and content type headers.","ref":"Anthropic.HttpClient.Utils.html#build_header/1-returns"},{"type":"function","title":"Examples - Anthropic.HttpClient.Utils.build_header/1","doc":"iex> Anthropic.HttpClient.Utils.build_header(%Anthropic.Config{api_key: \"your_api_key\", anthropic_version: \"2023-01\"})\n    [\n      {\"x-api-key\", \"your_api_key\"},\n      {\"anthropic-version\", \"2023-01\"},\n      {\"content-type\", \"application/json\"}\n    ]","ref":"Anthropic.HttpClient.Utils.html#build_header/1-examples"},{"type":"function","title":"Anthropic.HttpClient.Utils.build_path/2","doc":"Builds the complete request URL from a base API URL and a specific path.\n\nThis function constructs the full URL by appending the given path to the base API URL. It is designed to ensure that the URL structure is correctly formed for API requests.","ref":"Anthropic.HttpClient.Utils.html#build_path/2"},{"type":"function","title":"Parameters - Anthropic.HttpClient.Utils.build_path/2","doc":"- `path`: The specific API endpoint path to be appended to the base URL.\n- `api_url`: The base URL of the API.","ref":"Anthropic.HttpClient.Utils.html#build_path/2-parameters"},{"type":"function","title":"Returns - Anthropic.HttpClient.Utils.build_path/2","doc":"- A string representing the complete URL for the API request.","ref":"Anthropic.HttpClient.Utils.html#build_path/2-returns"},{"type":"function","title":"Examples - Anthropic.HttpClient.Utils.build_path/2","doc":"iex> Anthropic.HTTPClient.Utils.build_path(\"/v1/models\", \"https://api.anthropic.com\")\n    \"https://api.anthropic.com/v1/models\"","ref":"Anthropic.HttpClient.Utils.html#build_path/2-examples"},{"type":"module","title":"Anthropic.Messages.Content.Image","doc":"A module dedicated to processing image content within the [Anthropic ecosystem](https://docs.anthropic.com/claude/docs/vision).\nThis module offers functionality for validating, processing, and converting images to\nbase64 encoded strings, ensuring they meet specific criteria such as supported file types\nand dimensions.","ref":"Anthropic.Messages.Content.Image.html"},{"type":"module","title":"Features - Anthropic.Messages.Content.Image","doc":"- Supports multiple image formats: JPEG, PNG, GIF, and WEBP.\n- Validates images against a set of predefined dimensions and aspect ratios.\n- Converts images to a base64 encoded string for easy transmission and storage.\n- Provides detailed error handling for various failure scenarios during image processing.","ref":"Anthropic.Messages.Content.Image.html#module-features"},{"type":"module","title":"Usage - Anthropic.Messages.Content.Image","doc":"The primary entry point to the module is the `process_image/2` function, which takes an image input\nand an input type. The image input can be specified as a binary data, a file path, or a base64 encoded string.\nThe function returns a structured map with the image's metadata and base64 encoded content if successful,\nor an error message if not.\n\n#","ref":"Anthropic.Messages.Content.Image.html#module-usage"},{"type":"module","title":"Supported Input Types - Anthropic.Messages.Content.Image","doc":"- `:binary` - Direct binary data of the image.\n- `:path` - A file system path to the image.\n- `:base64` - A base64 encoded string of the image.\n\n#","ref":"Anthropic.Messages.Content.Image.html#module-supported-input-types"},{"type":"module","title":"Example - Anthropic.Messages.Content.Image","doc":"Anthropic.Messages.Content.Image.process_image(\"/path/to/image.png\", :path)\n\nThis function returns an `{:ok, response}` tuple on success, where `response` is a map that includes the type,\nsource type, media type, and base64 data of the image. On failure, it returns `{:error, error_message}`.","ref":"Anthropic.Messages.Content.Image.html#module-example"},{"type":"function","title":"Anthropic.Messages.Content.Image.process_image/2","doc":"Processes the given image input based on the specified input type and converts it into a base64 encoded string.","ref":"Anthropic.Messages.Content.Image.html#process_image/2"},{"type":"function","title":"Parameters - Anthropic.Messages.Content.Image.process_image/2","doc":"- `image_input`: The image input, which can be binary data, a file path, or a base64 encoded string.\n- `input_type`: A symbol indicating the type of the `image_input` (`:binary`, `:path`, `:base64`).","ref":"Anthropic.Messages.Content.Image.html#process_image/2-parameters"},{"type":"function","title":"Returns - Anthropic.Messages.Content.Image.process_image/2","doc":"An `{:ok, response}` tuple containing the processed image information or `{:error, reason}` on failure.","ref":"Anthropic.Messages.Content.Image.html#process_image/2-returns"},{"type":"type","title":"Anthropic.Messages.Content.Image.dimensions/0","doc":"","ref":"Anthropic.Messages.Content.Image.html#t:dimensions/0"},{"type":"type","title":"Anthropic.Messages.Content.Image.image_input/0","doc":"","ref":"Anthropic.Messages.Content.Image.html#t:image_input/0"},{"type":"type","title":"Anthropic.Messages.Content.Image.input_type/0","doc":"","ref":"Anthropic.Messages.Content.Image.html#t:input_type/0"},{"type":"type","title":"Anthropic.Messages.Content.Image.mime_type/0","doc":"","ref":"Anthropic.Messages.Content.Image.html#t:mime_type/0"},{"type":"type","title":"Anthropic.Messages.Content.Image.process_output/0","doc":"","ref":"Anthropic.Messages.Content.Image.html#t:process_output/0"},{"type":"type","title":"Anthropic.Messages.Content.Image.response/0","doc":"","ref":"Anthropic.Messages.Content.Image.html#t:response/0"},{"type":"type","title":"Anthropic.Messages.Content.Image.supported_size/0","doc":"","ref":"Anthropic.Messages.Content.Image.html#t:supported_size/0"},{"type":"module","title":"Anthropic.Messages.Request","doc":"Defines the structure and functionality for creating and sending requests to the Anthropic API.\n\nThis module encapsulates the data needed for a request, including model specifications, messages, and various control parameters.\nIt also implements the `Jason.Encoder` protocol to serialize instances of this struct to JSON format for API requests.\n\nConfiguration options:\n- `:model` - The name of the model to use for generating responses (default: \"claude-3-opus-20240229\").\n- `:max_tokens` - The maximum number of tokens allowed in the generated response (default: 1000).\n- `:temperature` - The sampling temperature for controlling response randomness (default: 1.0).\n- `:top_p` - The cumulative probability threshold for nucleus sampling (default: 1.0).\n- `:top_k` - The number of most probable next words considered at each step in sampling for text generation (default: nil).","ref":"Anthropic.Messages.Request.html"},{"type":"function","title":"Anthropic.Messages.Request.__struct__/0","doc":"The structure of a request to the Anthropic API.\n\nIncludes all necessary fields for making a request, such as model information, messages to process, and parameters to control the behavior of the API response.","ref":"Anthropic.Messages.Request.html#__struct__/0"},{"type":"function","title":"Anthropic.Messages.Request.create/1","doc":"Creates a new request struct based on the provided configuration.\n\nInitializes a request with the parameters specified in the configuration, setting up default values for the request structure.","ref":"Anthropic.Messages.Request.html#create/1"},{"type":"function","title":"Parameters - Anthropic.Messages.Request.create/1","doc":"- `opts`: Keyword list containing configuration options for the request.","ref":"Anthropic.Messages.Request.html#create/1-parameters"},{"type":"function","title":"Returns - Anthropic.Messages.Request.create/1","doc":"A new `Anthropic.Messages.Request` struct initialized with the provided configuration options.","ref":"Anthropic.Messages.Request.html#create/1-returns"},{"type":"function","title":"Anthropic.Messages.Request.send_request/2","doc":"Encodes the request to JSON and sends it to the Anthropic API via the Finch HTTP client.\n\nThis function serializes the request struct into JSON, builds the request with the correct headers and path, and sends it using Finch.","ref":"Anthropic.Messages.Request.html#send_request/2"},{"type":"function","title":"Parameters - Anthropic.Messages.Request.send_request/2","doc":"- `request`: The Anthropic.Messages.Request struct to send.\n- `opts`: Additional options for the Finch request.","ref":"Anthropic.Messages.Request.html#send_request/2-parameters"},{"type":"function","title":"Returns - Anthropic.Messages.Request.send_request/2","doc":"- `{:ok, response}` on successful request and response parsing.\n- `{:error, reason}` if the request fails due to encoding issues or HTTP errors.","ref":"Anthropic.Messages.Request.html#send_request/2-returns"},{"type":"type","title":"Anthropic.Messages.Request.content_object/0","doc":"","ref":"Anthropic.Messages.Request.html#t:content_object/0"},{"type":"type","title":"Anthropic.Messages.Request.message/0","doc":"","ref":"Anthropic.Messages.Request.html#t:message/0"},{"type":"type","title":"Anthropic.Messages.Request.t/0","doc":"","ref":"Anthropic.Messages.Request.html#t:t/0"},{"type":"module","title":"Anthropic.Messages.Response","doc":"Handles parsing and encapsulation of responses from the Anthropic API.\n\nThis module defines the structure of a response from the Anthropic API and provides functionality to parse the raw response into a structured format. It deals with successful responses as well as various error conditions, translating HTTP responses into a consistent format for the caller to handle.","ref":"Anthropic.Messages.Response.html"},{"type":"function","title":"Anthropic.Messages.Response.parse/2","doc":"Parses an HTTP response from the Anthropic API.\n\nThis function handles different types of HTTP responses based on their status code. It extracts relevant fields from successful responses (status 200) and constructs a struct representing the parsed response. For error responses (status codes 400-499 for client errors and 500-599 for server errors), it returns an error tuple. Errors encountered during the HTTP request process are also passed through.","ref":"Anthropic.Messages.Response.html#parse/2"},{"type":"function","title":"Parameters - Anthropic.Messages.Response.parse/2","doc":"- `response`: A tuple containing the raw HTTP response. This can be either `{:ok, %Finch.Response{}}` indicating a potentially successful or error response, or `{:error, response}` indicating an error during the request process.","ref":"Anthropic.Messages.Response.html#parse/2-parameters"},{"type":"function","title":"Returns - Anthropic.Messages.Response.parse/2","doc":"- For successful responses (status 200), returns `{:ok, response_struct}` where `response_struct` is the struct representation of the parsed response.\n- For client errors (status codes 400-499) and server errors (status codes 500-599), returns `{:error, response}` where `response` is the original response indicating an error.\n- For errors during the request process, returns `{:error, response}` where `response` is the original error response.","ref":"Anthropic.Messages.Response.html#parse/2-returns"},{"type":"type","title":"Anthropic.Messages.Response.invocation/0","doc":"","ref":"Anthropic.Messages.Response.html#t:invocation/0"},{"type":"type","title":"Anthropic.Messages.Response.t/0","doc":"","ref":"Anthropic.Messages.Response.html#t:t/0"},{"type":"behaviour","title":"Anthropic.Tools.ToolBehaviour","doc":"Defines a behaviour for creating tools that can be used with Anthropic's AI models.\n\nThis module provides a set of callbacks and basic functions to support tool description\nand invocation, as described in the [Anthropic documentation](https://docs.anthropic.com/claude/docs/functions-external-tools).\n\nTo create a new tool, define a module that implements the `Anthropic.Tools.ToolBehaviour` behaviour.\nThe module should implement the following callbacks:\n\n- `description/0`: Returns a string describing the purpose and functionality of the tool.\n- `parameters/0`: Returns a list of parameter specifications, where each parameter is represented\n  as a tuple of `{name, type, description}`.\n- `invoke/1`: Invokes the tool with the provided Keyword list arguments and returns the result\n  as a string.\n\nExample:\n\n    defmodule MyTool do\n      use Anthropic.Tools.ToolBehaviour\n\n      def description do\n        \"A tool that performs a specific task.\"\n      end\n\n      def parameters do\n        [\n          {:param1, :string, \"Description of param1.\"},\n          {:param2, :integer, \"Description of param2.\"}\n        ]\n      end\n\n      def invoke(keyword_list) do\n        # Implement the tool's functionality here\n        # Use the provided arguments to perform the task\n        # Return the result as a string\n      end\n    end","ref":"Anthropic.Tools.ToolBehaviour.html"},{"type":"callback","title":"Anthropic.Tools.ToolBehaviour.description/0","doc":"Returns a string describing the purpose and functionality of the tool.","ref":"Anthropic.Tools.ToolBehaviour.html#c:description/0"},{"type":"callback","title":"Anthropic.Tools.ToolBehaviour.invoke/1","doc":"Invokes the tool with the provided list of string arguments and returns the result as a string.","ref":"Anthropic.Tools.ToolBehaviour.html#c:invoke/1"},{"type":"callback","title":"Anthropic.Tools.ToolBehaviour.parameters/0","doc":"Returns a list of parameter specifications for the tool.\n\nEach parameter is represented as a tuple of `{name, type, description}`, where:\n- `name` is an atom representing the parameter name.\n- `type` is an atom representing the parameter type (`:string`, `:float`, or `:integer`).\n- `description` is a string describing the purpose of the parameter.","ref":"Anthropic.Tools.ToolBehaviour.html#c:parameters/0"},{"type":"type","title":"Anthropic.Tools.ToolBehaviour.parameter/0","doc":"","ref":"Anthropic.Tools.ToolBehaviour.html#t:parameter/0"},{"type":"type","title":"Anthropic.Tools.ToolBehaviour.parameter_type/0","doc":"","ref":"Anthropic.Tools.ToolBehaviour.html#t:parameter_type/0"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}